ImageSet
========

.. currentmodule:: wwt_data_formats.imageset

.. autoclass:: ImageSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageSet.band_pass
      ~ImageSet.base_degrees_per_tile
      ~ImageSet.base_tile_level
      ~ImageSet.bottoms_up
      ~ImageSet.center_x
      ~ImageSet.center_y
      ~ImageSet.credits
      ~ImageSet.credits_url
      ~ImageSet.data_set_type
      ~ImageSet.dem_url
      ~ImageSet.description
      ~ImageSet.elevation_model
      ~ImageSet.file_type
      ~ImageSet.generic
      ~ImageSet.mean_radius
      ~ImageSet.msr_community_id
      ~ImageSet.msr_component_id
      ~ImageSet.name
      ~ImageSet.offset_x
      ~ImageSet.offset_y
      ~ImageSet.permission
      ~ImageSet.projection
      ~ImageSet.quad_tree_map
      ~ImageSet.reference_frame
      ~ImageSet.rotation_deg
      ~ImageSet.sparse
      ~ImageSet.stock_set
      ~ImageSet.thumbnail_url
      ~ImageSet.tile_levels
      ~ImageSet.url
      ~ImageSet.width_factor

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageSet.set_position_from_wcs
      ~ImageSet.wcs_headers_from_position

   .. rubric:: Attributes Documentation

   .. autoattribute:: band_pass
   .. autoattribute:: base_degrees_per_tile
   .. autoattribute:: base_tile_level
   .. autoattribute:: bottoms_up
   .. autoattribute:: center_x
   .. autoattribute:: center_y
   .. autoattribute:: credits
   .. autoattribute:: credits_url
   .. autoattribute:: data_set_type
   .. autoattribute:: dem_url
   .. autoattribute:: description
   .. autoattribute:: elevation_model
   .. autoattribute:: file_type
   .. autoattribute:: generic
   .. autoattribute:: mean_radius
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: offset_x
   .. autoattribute:: offset_y
   .. autoattribute:: permission
   .. autoattribute:: projection
   .. autoattribute:: quad_tree_map
   .. autoattribute:: reference_frame
   .. autoattribute:: rotation_deg
   .. autoattribute:: sparse
   .. autoattribute:: stock_set
   .. autoattribute:: thumbnail_url
   .. autoattribute:: tile_levels
   .. autoattribute:: url
   .. autoattribute:: width_factor

   .. rubric:: Methods Documentation

   .. automethod:: set_position_from_wcs
   .. automethod:: wcs_headers_from_position
